﻿Type=Class
Version=3.71
ModulesStructureVersion=1
B4J=true
@EndOfDesignText@
'Class module
Sub Class_Globals
	Private fx As JFX
	Private conmap, temperaturemap As Map
End Sub

Public Sub Initialize
	conmap.Initialize
	temperaturemap.Initialize
	'length / default unit: meter
	conmap.Put("meter","1")
	conmap.Put("millimeter","1000")
	conmap.Put("centimeter","100")
	conmap.Put("decimeter","10")
	conmap.Put("kilometer","0.001")
	conmap.Put("foot","3.28084")
	conmap.Put("inch","39.37008")
	conmap.Put("mile","0.00062137121212121")
	conmap.Put("yard","1.0936133333333297735")
	
	'Volume / default unit: liter
	conmap.Put("liter","1")
	conmap.Put("cubic foot","0.0353147")
	conmap.Put("cubic inch","61.0237")
	conmap.Put("cubic mile","0.0000000000002399127586")
	conmap.Put("cubic yard","0.00130795")
	conmap.Put("cup","4.22675")
	conmap.Put("Imperial gallon","0.219969")
	conmap.Put("US gallon","0.264172")
	conmap.Put("milliliter","1000")
	conmap.Put("Imperial fluid ounce","35.1951")
	conmap.Put("US fluid ounce","33.814")
	conmap.Put("Imperial pint","1.75975")
	conmap.Put("US pint (liquid)","2.113376")
	conmap.Put("US pint (dry)","1.816166")
	conmap.Put("Imperial quart","0.879877")
	conmap.Put("US quart (liquid)","1.056688")
	conmap.Put("US quart (dry)","1.816166")
	conmap.Put("tablespoon","67.628")
	conmap.Put("teaspoon","202.884")
	
	'weight / default unit: kilogram
	conmap.Put("kilogram","1")
	conmap.Put("milligram","1000000")
	conmap.Put("gram","1000")
	conmap.Put("carat","5000")
	conmap.Put("grain","15432.4")
	conmap.Put("ounce","35.274")
	conmap.Put("pennyweight","643.015")
	conmap.Put("pound","2.20462")
	conmap.Put("stone","0.157473")
	conmap.Put("slug","0.0685218")
	conmap.Put("metric ton","0.001")
	conmap.Put("long ton","0.000984207")
	conmap.Put("short ton","0.00110231")
	
	'Area / default unit: square meter
	conmap.Put("square meter","1")
	conmap.Put("acre","0.000247105")
	conmap.Put("are","0.01")
	conmap.Put("hectare","0.0001")
	conmap.Put("square foot","10.7639")
	conmap.Put("square kilometer","0.000001")
	conmap.Put("square inch","1550")
	conmap.Put("square yard","1.19599")
	conmap.Put("square mile","0.0000003861021585")
	conmap.Put("aankadam","0.14951933")
	conmap.Put("perch","0.0395368610347")
	conmap.Put("cent","0.0247105407259")
	conmap.Put("chatak","0.02391956")
	conmap.Put("kottah","0.01494892")
	conmap.Put("guntha","0.00988342")
	conmap.Put("ground","0.00448496460466")
	conmap.Put("marla","0.0019936")
	conmap.Put("rood","0.00098813")
	conmap.Put("bigha I","0.00061677")
	conmap.Put("bigha II","0.00039537")
	conmap.Put("kanal","0.00199348")
	conmap.Put("biswa I","0.00003014")
	conmap.Put("biswa II","0.00001977")

	'Pressure / default unit: bar
	conmap.Put("bar","1")
	conmap.Put("pascal","100000")
	conmap.Put("torr","750.062")
	conmap.Put("millibar","1000")
	conmap.Put("psi","14.5038")
	
	'Time / default unit: hour
	conmap.Put("hour","1")
	conmap.Put("day","0.0416667")
	conmap.Put("minute","60")
	conmap.Put("year","0.000114155")
	
'	Temperature / (different map)
	temperaturemap.Put("celsius"&"celsius","0|1")
	temperaturemap.Put("celsius"&"fahrenheit","32|1.8")
	temperaturemap.Put("celsius"&"kelvin","273.15|1")
	temperaturemap.Put("fahrenheit"&"fahrenheit","0|1")
	temperaturemap.Put("fahrenheit"&"celsius","-17.7778|0.5556")
	temperaturemap.Put("fahrenheit"&"kelvin","255.372|0.556")
	temperaturemap.Put("kelvin"&"kelvin","0|1")
	temperaturemap.Put("kelvin"&"celsius","-273.15|1")
	temperaturemap.Put("kelvin"&"fahrenheit","-459.67|1.8")	
	
End Sub

'
'Convert Initial unit to Target unit.
'value: Amount to calculate
'confrom: Enter the Initial unit as written in the array, example: "millimeter","centimeter",...
'conto: Enter the Target unit as written in the array, example: "millimeter","centimeter",...
Public Sub convert(value As String, confrom As String, conto As String) As Double
	Dim result As Double
	Dim tempstring As String = "celsius,fahrenheit,kelvin"
	Dim timestring As String = "day,hour,minute,year"
	If value = "" Then Return 0
	value = value.Replace(",",".")
		
	If tempstring.Contains(confrom) Then 'temperature map
		Dim str() As String = Regex.Split("\|",getunit2(confrom & conto))
		result = NumberFormat2(str(0) + (value * str(1)),1,2,0,False)	
	else if timestring.Contains(confrom) Then 'round instead of numberformat
		If confrom = "year" Then 
			result = Round((value / getunit(confrom)) * getunit(conto))
		else If confrom = "day" Then 
			If conto = "hour" Or conto = "minute" Then 
				result = Round((value / getunit(confrom)) * getunit(conto))
			Else 
				result = NumberFormat2((value / getunit(confrom)) * getunit(conto),1,5,0,False)	
			End If	
		Else if confrom = "hour" And conto = "minute" Then 
			result = Round((value / getunit(confrom)) * getunit(conto))
		Else 
			result = NumberFormat2((value / getunit(confrom)) * getunit(conto),1,5,0,False)		
		End If	
	Else 
		result = NumberFormat2((value / getunit(confrom)) * getunit(conto),1,5,0,False)	
	End If
	
	Return result
End Sub

Sub getunit(unit As String) As Double
	Dim value As Double
	value = conmap.Get(unit)
	Return value
End Sub

Sub getunit2(unit As String) As String
	Dim value As String
	value = temperaturemap.Get(unit)
	Return value
End Sub